@@ -1,4 +1,6 @@
 from sqlalchemy import create_engine
+from sqlalchemy.ext.declarative import declarative_base
+from sqlalchemy.orm import sessionmaker
 
 from bolinette import env, db
 from bolinette.utils import logger
@@ -9,21 +11,26 @@ class Engine:
         self.engine = None
         self.session = None
         self.seeders = []
+        self.Session = None
+        self.model = None
 
     def init_app(self):
         self.engine = create_engine(self._create_uri(), echo=False)
-        db.defs.Session.configure(bind=self.engine)
-        self.session = db.defs.Session()
+        self.Session = sessionmaker()
+        self.model = declarative_base()
+        self.Session.configure(bind=self.engine)
+        self.session = self.Session()
+        db.models.init_models()
 
     def seeder(self, func):
         self.seeders.append(func)
         return func
 
     async def create_all(self):
-        db.defs.model.metadata.create_all(self.engine)
+        self.model.metadata.create_all(self.engine)
 
     async def drop_all(self):
-        db.defs.model.metadata.drop_all(self.engine)
+        self.model.metadata.drop_all(self.engine)
 
     async def run_seeders(self):
         for func in self.seeders:
